#!/bin/ksh
#
# Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
# Use is subject to license terms.
#
#ident  "@(#)install.sh 1.2     06/05/04 SMI"
#

f_CHECKOS()
{
    # Valid OS levels are Solaris 11
    MIN_OS=11
    MAX_OS=11
    OS_VER=`uname -r`
    OS_NUM=`echo $OS_VER | cut -d"." -f2`

    # less than min or greater than max, exit
    if [ $OS_NUM -lt $MIN_OS -o $OS_NUM -gt $MAX_OS ]
    then
        f_OSBAD
        exit 1
    fi
}

f_CPFILE()
{
    if [ -w $DESTDIR ]
    then
       cp $SUPFILE $DESTDIR
       if [ $? -ne 0 ]
       then
          echo "Installation of file $DESTDIR/$SUPFILE failed."
          exit 1
       fi	 
    else
       echo "Directory $DESTDIR is not writable."
       echo "Exiting..."
       exit 1
    fi
}

f_SLA()
{
    # Display SLA 
    ans=`ckyorn -Q -d y -p "Display software license agreement"`
    case $ans in
        y|Y|yes|YES)
	    less opensolaris.license.txt
            break
            ;; 
    esac
    
    echo "\n"

    ans=`ckyorn -Q -p "Do you agree to the terms and conditions stated in software license agreement"`
    case $ans in
        y|Y|yes|YES)
            break
            ;; 
        *)
            echo "\nInstallation cancelled!\n"
            exit 0
            ;;
    esac
}


f_SETPKGVARS()
{
    II="SUNWiiu SUNWiir"
    SNDR="SUNWrdcu SUNWrdcr"
    CORE="SUNWspsvu SUNWspsvr SUNWscmu SUNWscmr"
    
    # concat all functional pkgs
    ALLBADPKGS="$II $SNDR $CORE"
}

f_USER()
{
    # ensure that user is root
    uid=`id | sed 's/uid=\([0-9]*\)(.*/\1/'`
    if [ $uid -ne 0 ]
    then
        echo "\nWARNING: You are currently not the root user."
        echo "You must be root when you execute the installation"
        echo "scripts.\n"
        exit 1
    fi
}

f_PASS_PROD()
{
    if [ "$PROD" = "CORE" ] 
    then
        echo "\n$PROD software package installation complete."
        echo "Continuing..."
    fi

    if [ "$PROD" = "remote mirror software"  -o \
         "$PROD" = "point-in-time copy software" ]
    then
        echo "\nInstallation of $PROD is complete."
    fi
}

f_PASS_SUITE()
{
    echo "\nInstallation of Availability Suite 4.0 is complete."
    echo "\n\nConfiguring  Availability Suite 4.0 for first time use."
    /usr/sbin/dscfgadm
    exit 0

}

f_FAIL_MESSAGE()
{
    if [ "$PROD" = "CORE" ]
    then
        echo "\nThere was an error installing the $PROD packages;"
        echo "the required packages for point-in-time copy and"
        echo "remote mirror software." 
        exit 1
    else
        echo "\nThere was an error installing $PROD."
        exit 1
    fi
}

f_CONTINUE_LOOP()
{
    ans=`ckyorn -Qd n -p "Do you want to continue"`
    case $ans in
        y|Y|yes|YES)
            break
            ;; 
        *)
            echo "\nInstallation cancelled!\n"
            exit 0
            ;;
    esac
}

f_PROMPT()
{
    # ask user what root is for where they are installing.
    echo "\nNote: The following should only be changed from the"
    echo "default (/) if installation is occurring on a remotely"
    echo "mounted device.  ex: in jumpstart environment"
    ans=`ckpath  -aorwQ -d "/" -p "What is the root_path for \
this package installation? [ / ] "`
    if [ $ans ]
    then
        PKG_INSTALL_ROOT=$ans
    else
        PKG_INSTALL_ROOT="/"
    fi
}

f_ADMIN()
{
     touch $ADMIN_FILE

     echo "basedir=default" >> $ADMIN_FILE
     echo "mail=" >> $ADMIN_FILE
     echo "runlevel=nocheck" >> $ADMIN_FILE
     echo "conflict=nocheck" >> $ADMIN_FILE
     echo "setuid=nocheck" >> $ADMIN_FILE
     echo "action=nocheck" >> $ADMIN_FILE
     echo "partial=quit" >> $ADMIN_FILE
     echo "instance=quit" >> $ADMIN_FILE
     echo "idepend=quit" >> $ADMIN_FILE
     echo "rdepend=nocheck" >> $ADMIN_FILE
     echo "space=quit" >> $ADMIN_FILE
}

f_USAGE()
{
    printf "`basename $0` usage:\n\n"
    printf "\tInstall Availability Suite:\t\t `basename $0` [-j] -a \n"
    printf "\tInstall point-in-time copy software:\t `basename $0` [-j] -p \n"
    printf "\tInstall remote mirror software:\t\t `basename $0` [-j] -r \n\n"
}


f_CK()
{
    # check if pkg(s) are loaded
    CK=0

    # let user know what's up
    printf "\nChecking $PROD package status."

    for PKG in $MYPKGS
    do 
      # check if installed
      printf "."
      pkginfo -R $PKG_INSTALL_ROOT $PKG > /dev/null 2>&1
      
      if [ $? -eq 0 ]
      then
          # check status of pkg installation
          pkgchk -R $PKG_INSTALL_ROOT -a $PKG > /dev/null 2>&1
          # if pkgchk exits 1, then we have a partial installation
          if [ $? -eq 1 ]
          then
              echo "\n\nERROR: A previous installation of package $PKG"
              echo "was not complete.  Please remove this package with"
              echo "the command pkgrm, then re-run `basename $0`."
              exit 1
          fi
      else
          CK=1
          break
      fi
    done
    printf "\n"

    # if not, load it/them.
    if [ $CK -eq 1 ]
    then
        f_LOAD
    else
        if [ $SUITE = 1 ]
        then
            f_PASS_SUITE
        else
            if [ $AVAIL = 1 ]
            then
                continue
            else
                f_PASS_PROD
            fi
        fi
    fi
}

f_LOAD()
{
    # if doesn't already exist, populate admin file
    if [ ! -f $ADMIN_FILE ]
    then
        f_ADMIN
    fi

    # check available space (even though pkgadd does this, 
    # we must trap first to avoid ugly errors)
    # grab avail space from df -k, and warn if under 
    #50mb free. (51200k = 50mb)
    CAPACITYa=`df -k $PKG_INSTALL_ROOT | awk '{print $4}' | tail -1`
    CAPACITYb=`df -k $PKG_INSTALL_ROOT$BASEDIR | awk '{print $4}' | tail -1`
    if [ $CAPACITYa -lt 51200  -o  $CAPACITYb -lt 51200 ]
    then
        f_WARNING_SPACE
    fi

    # load software
    for PKG in $MYPKGS
    do
      pkgadd -R $PKG_INSTALL_ROOT -a $ADMIN_FILE -d . $PKG 2>&1
      if [ $? -ne $RET_SUCCESS  -a  $? -ne $RET_ADMIN  -a  \
          $? -ne $RET_REBOOT ]
      then       
          f_FAIL_MESSAGE
      fi
    done
    
    if [ $SUITE = 1 ]
    then
        f_PASS_SUITE
    else
        if [ $AVAIL = 1 ]
        then
            continue
        else
            f_PASS_PROD
        fi
    fi
}


#
# MAIN
#

# set variables
PATH=/usr/bin:/usr/sbin
export PATH

SAME_VER=0
TEST=0
ARG_ONE=$1
ARG_TWO=$2
ADMIN_FILE=/var/tmp/admin_file

#set this to "normal" ie: "/", it will only have the chance
#to change when user selects "-j" option.
PKG_INSTALL_ROOT="/"

PITPKGS="SUNWiir SUNWiiu"
RMPKGS="SUNWrdcr SUNWrdcu"
COREPKGS="SUNWscmr SUNWscmu SUNWspsvr SUNWspsvu"

RET_SUCCESS=0
RET_ADMIN=4
RET_REBOOT=10
AVAIL=0
SUITE=0

#set here since most of pkg is installed in usr dir, is 
#changed later by pkgs if needed
BASEDIR="/usr"

#set these in case later the locations (pkg_inst_root, 
#basedir) don't exist, pkgadd will prompt for errors if needed
CAPACITYa=0
CAPACITYb=0
NULL=`cat /dev/null`

# ensure user is root
f_USER
OPT_J="no"

# Set default to all
ARG_REC="a"

#Verify that Solaris version is supported.
f_CHECKOS

#set up all pkg variables needed to run the probe_script portion
f_SETPKGVARS

# Display, approve and install Sun Software Legal Agreement and Entitlements.
f_SLA

case $ARG_REC in
    p) 
        PROD="CORE"
        MYPKGS="$COREPKGS"
        f_CK
        PROD="point-in-time copy software"
        MYPKGS="$PITPKGS"
        f_CK
        rm -f $ADMIN_FILE
        ;;
    r)
        PROD="CORE"
        MYPKGS="$COREPKGS"
        f_CK
        PROD="remote mirror software"
        MYPKGS="$RMPKGS"
        f_CK
        rm -f $ADMIN_FILE
        ;;
    a)
        AVAIL=1
        PROD="CORE"
        MYPKGS="$COREPKGS"
        f_CK
        PROD="point-in-time copy software"
        MYPKGS="$PITPKGS"
        f_CK
        PROD="remote mirror software"
        MYPKGS="$RMPKGS"
        SUITE=1
        f_CK
        rm -f $ADMIN_FILE
        ;;
esac
