/*
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License (the "License").  
 * You may not use this file except in compliance with the License.
 *
 * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
 * or http://www.opensolaris.org/os/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 */
/*
 * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
 * Use is subject to license terms.
 */

#pragma ident   "@(#)ds_get.c 1.6     07/01/12 SMI"

#include <sys/types.h>
#include <stdio.h>
#include <errno.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <strings.h>

#include <locale.h>
#include <langinfo.h>
#include <libintl.h>

#include <sys/nsctl/cfg.h>

char tag[CFG_MAX_BUF]; 		/* tag to get */
char field[CFG_MAX_BUF];	/* Field to get */
char logical_host[CFG_MAX_BUF];	/* Cluster tag */

static void
usage(int error)
{
	(void) printf(
	    gettext("ds_get -h         display this help message\n"));
	(void) printf(
	    gettext("ds_get -f str     retrieve field str\n"));
	(void) printf(
	    gettext("ds_get -n n       retrieve instance n\n"));
	(void) printf(
	    gettext("ds_get -t         retrieve tag str\n"));
	(void) printf(
	    gettext("ds_get -C ctag    retrieve only ctag\n"));

	exit(error);
	/*NOTREACHED*/
}

#ifdef lint
int
ds_get_lintmain(int argc, char *argv[])
#else
int
main(int argc, char *argv[])
#endif
{
	extern int optind;
	int rc;
	int instance = 1;
	char c;
	CFGFILE *cfg;
	char buf[CFG_MAX_BUF];
	char key[CFG_MAX_BUF];

	(void) setlocale(LC_ALL, "");
	(void) textdomain("ds_get");

	while ((c = getopt(argc, argv, "hf:n:t:C:")) != EOF) {
		switch (c) {
			case 'h':
				usage(0);
				/* NOTREACHED */

			case 'f':
				strcpy(field, optarg);
				break;
			case 't':
				strcpy(tag, optarg);
				break;

			case 'n':
				instance = atoi(optarg);
				break;

			case 'C':
				strcpy(logical_host, optarg);
				break;

			default:
				(void) fprintf(stderr,
				    gettext("ds_get: unknown command "
				    "line argument '%c'\n"), c);
				usage(1);
		}
	}
	if (argc == 1) {
		exit(1);
		/* NOTREACHED */
	}

	if (optind != argc) {
		(void) fprintf(stderr,
		    gettext("dsclinfo: too many command line arguments\n"));
		usage(1);
		/* NOTREACHED */
	}

	cfg = cfg_open(NULL);

	if (cfg == NULL) {
		(void) fprintf(
		    stderr, gettext("ds_get: %s\n"), cfg_error(NULL));
		exit(2);
	}

	if (!cfg_lock(cfg, CFG_RDLOCK)) {
		(void) fprintf(stderr, gettext("cfg_lock: lock failed\n"));
		exit(1);
	}
	/*
	 * Set cluster node to return everything
	 */
	if (logical_host[0] != '\0')
		cfg_resource(cfg, logical_host);
	else
		cfg_resource(cfg, NULL);
	bzero(buf, CFG_MAX_BUF);
	bzero(key, CFG_MAX_BUF);
	if (strlen(field) > 0)
		(void) snprintf(key, sizeof (key), "%s.set%d.%s", tag,
			instance, field);
	else
		(void) snprintf(key, sizeof (key), "%s.set%d", tag, instance);
	rc = cfg_get_cstring(cfg, key, buf, CFG_MAX_BUF);
	if (rc < 0) {
		cfg_close(cfg);
		exit(1);
		/*NOTREACHED*/
	}

	(void) printf("%s\n", buf);
#ifdef XXXJET
	/*
	 * Set cluster node to return everything
	 */
	if (logical_host[0] != '\0')
		cfg_resource(fd, logical_host);
	else
		cfg_resource(fd, NULL);
#endif
	cfg_close(cfg);
	return (0);
}
