/*
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License (the "License").  
 * You may not use this file except in compliance with the License.
 *
 * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
 * or http://www.opensolaris.org/os/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 */
/*
 * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
 * Use is subject to license terms.
 */

#pragma	ident	"@(#)sd_ckd.c	1.21	07/01/12 SMI"

/*
 * Extracted from "stxprint.c",
 *    Copyright (c) Fundamental Software, Inc., 1994
 *    All Rights Reserved
 *
 *    Fundamental Software, Inc. considers this program a TRADE SECRET.
 */

#include <errno.h>
#include <string.h>
#include <memory.h>
#include <stdio.h>
#include <fcntl.h>
#include <stdlib.h>
#include <sys/nsctl/sd_trace.h>
#include "devtrace.h"
#include "dtstrings.h"
#include "polinc.h"

int
sortcmp(di1, di2)
	const void *di1, *di2;
{
	register struct dts *d1, *d2;

	d1 = (struct dts *) di1;
	d2 = (struct dts *) di2;

	if (d1 -> dtstf < d2 -> dtstf)
		return (-1);
	else if (d1 -> dtstf == d2 -> dtstf)
		return (0);
	else
		return (1);
}

ckd_init()
{
	/* sort format strings from dtstrings.h */
	qsort((void*)dstrs, sizeof (dstrs)/sizeof (struct dts),
		sizeof (struct dts), sortcmp);
}

/*
 * format a trace entry according to the trace entry table.
 * NB: trace entry is encoded in the SD trace
 */
#define	tf	t_len
#define	ttime	t_time
#define	tw1	t_fba
#define	tw2	t_flg
#define	tw3	t_ret
/* #define tw4	/* not stored? */

ckd_format(t, workstr)
	struct _sdtr *t;	/* trace entry */
	char *workstr;
{
	struct dts *p;
	struct dts cmpdts;

	cmpdts.dtstf = t -> tf;
	cmpdts.dtsstr = NULL;

	p = (struct dts *)bsearch((void*)&cmpdts, (void*)dstrs,
				sizeof (dstrs)/sizeof (struct dts),
				sizeof (struct dts), sortcmp);
	if (p == NULL) {
		sprintf(workstr, "TYPE = %04x; Data = %08x, %08x, %08x",
			t -> tf, t -> tw1, t -> tw2, t -> tw3);
		return;
	}

	sprintf(workstr, p -> dtsstr, t -> tw1, t -> tw2, t -> tw3,
		/* t -> tw4 */ 0);
}
